@@ -1,21 +1,5 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -64,7 +48,7 @@ class ExportManager: public QObject
     void setTimestamp(const QDateTime &timestamp);
     QString windowTitle() const;
     Spectacle::CaptureMode captureMode() const;
-    void setCaptureMode(const Spectacle::CaptureMode &theCaptureMode);
+    void setCaptureMode(Spectacle::CaptureMode theCaptureMode);
     QString formatFilename(const QString &nameTemplate);
 
     static const QMap<QString, KLocalizedString> filenamePlaceholders;
@@ -72,8 +56,9 @@ class ExportManager: public QObject
     Q_SIGNALS:
 
     void errorMessage(const QString &str);
-    void pixmapChanged(const QPixmap &pixmap);
     void imageSaved(const QUrl &savedAt);
+    void imageCopied();
+    void imageSavedAndCopied(const QUrl &savedAt);
     void forceNotify(const QUrl &savedAt);
 
     public Q_SLOTS:
@@ -84,7 +69,8 @@ class ExportManager: public QObject
     void setWindowTitle(const QString &windowTitle);
     void doSave(const QUrl &url = QUrl(), bool notify = false);
     bool doSaveAs(QWidget *parentWindow = nullptr, bool notify = false);
-    void doCopyToClipboard(bool notify);
+    void doSaveAndCopy(const QUrl &url = QUrl());
+    void doCopyToClipboard(bool notify = false);
     void doPrint(QPrinter *printer);
 
     private:
