@@ -1,22 +1,6 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright 2019 David Redondo <kde@david-redondo.de>
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -50,7 +34,8 @@
 #include <KGuiItem>
 #include <KHelpMenu>
 #include <KIO/OpenFileManagerWindowJob>
-#include <KRun>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -160,7 +145,7 @@ void KSMainWindow::init()
     mAnnotateButton->setToolTip(i18n("Add annotation to the screenshot"));
     mAnnotateButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mAnnotateButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
-    connect(mAnnotateButton, &QToolButton::pressed, this, [this] {
+    connect(mAnnotateButton, &QToolButton::clicked, this, [this] {
 
         if (mAnnotatorActive) {
             mKSWidget->hideAnnotator();
@@ -169,12 +154,13 @@ void KSMainWindow::init()
             mKSWidget->showAnnotator();
             mAnnotateButton->setText(i18n("Annotation done"));
         }
-        mAnnotatorActive = !mAnnotatorActive;
 
-        mToolsButton->setEnabled(!mAnnotatorActive);
-        mSendToButton->setEnabled(!mAnnotatorActive);
-        mClipboardButton->setEnabled(!mAnnotatorActive);
-        mSaveButton->setEnabled(!mAnnotatorActive);
+        mToolsButton->setEnabled(mAnnotatorActive);
+        mSendToButton->setEnabled(mAnnotatorActive);
+        mClipboardButton->setEnabled(mAnnotatorActive);
+        mSaveButton->setEnabled(mAnnotatorActive);
+
+        mAnnotatorActive = !mAnnotatorActive;
     });
 
     mDialogButtonBox->addButton(mAnnotateButton, QDialogButtonBox::ActionRole);
@@ -400,7 +386,9 @@ void KSMainWindow::showPrintDialog()
 
 void KSMainWindow::openScreenshotsFolder()
 {
-    new KRun(Settings::defaultSaveLocation(), this);
+    auto job = new KIO::OpenUrlJob(Settings::defaultSaveLocation());
+    job->setUiDelegate(new KIO::JobUiDelegate(KIO::JobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
 }
 
 void KSMainWindow::quit(const QuitBehavior quitBehavior)
