@@ -1,21 +1,5 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -26,6 +10,7 @@
 #include <QFrame>
 #include <QToolButton>
 #include <QDialogButtonBox>
+#include <QStackedLayout>
 
 #include <KMessageWidget>
 #include <KNS3/KMoreToolsMenuFactory>
@@ -35,6 +20,7 @@
 #include "KSWidget.h"
 #include "ExportMenu.h"
 #include "Platforms/Platform.h"
+#include "Config.h"
 
 #include <memory>
 
@@ -44,7 +30,7 @@ class KSMainWindow: public QDialog
 
     public:
 
-    explicit KSMainWindow(const Platform::GrabModes &theGrabModes, const Platform::ShutterModes &theShutterModes, QWidget *parent = nullptr);
+    explicit KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterModes theShutterModes, QWidget *parent = nullptr);
     virtual ~KSMainWindow() = default;
 
     enum class MessageDuration {
@@ -63,6 +49,7 @@ class KSMainWindow: public QDialog
                         const KMessageWidget::MessageType messageType,
                         const MessageDuration messageDuration = MessageDuration::AutoHide,
                         const QList<QAction*>& actions  = {});
+    int windowWidth(const QPixmap &pixmap) const;
 
     private Q_SLOTS:
 
@@ -76,7 +63,6 @@ class KSMainWindow: public QDialog
     void setDefaultSaveAction();
     void save();
     void saveAs();
-    int windowWidth(const QPixmap &pixmap) const;
     void restoreWindowTitle();
 
     public Q_SLOTS:
@@ -84,6 +70,7 @@ class KSMainWindow: public QDialog
     void setScreenshotAndShow(const QPixmap &pixmap);
     void imageSaved(const QUrl &location);
     void imageSavedAndCopied(const QUrl &location);
+    void screenshotFailed();
 
     Q_SIGNALS:
 
@@ -118,4 +105,10 @@ class KSMainWindow: public QDialog
     ExportMenu       *mExportMenu;
     Platform::ShutterModes mShutterModes;
     QTimer           *mHideMessageWidgetTimer;
+    QStackedLayout   *mStack;
+
+#ifdef KIMAGEANNOTATOR_FOUND
+    QToolButton      *mAnnotateButton;
+    bool             mAnnotatorActive;
+#endif
 };
