@@ -1,21 +1,5 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -26,6 +10,7 @@
 
 #include "SpectacleCommon.h"
 #include "Platforms/Platform.h"
+#include "Config.h"
 
 class QAction;
 class QGridLayout;
@@ -35,13 +20,18 @@ class QFormLayout;
 class QComboBox;
 class QCheckBox;
 class QLabel;
-
 class KConfigDialogManager;
+class QPushButton;
+class QStackedLayout;
 
 class KSImageWidget;
 class ProgressButton;
 class SmartSpinBox;
 
+namespace kImageAnnotator {
+    class KImageAnnotator;
+}
+
 class KSWidget : public QWidget
 {
     Q_OBJECT
@@ -73,6 +63,11 @@ class KSWidget : public QWidget
     void setButtonState(KSWidget::State state);
     void setProgress(double progress);
 
+#ifdef KIMAGEANNOTATOR_FOUND
+    void showAnnotator();
+    void hideAnnotator();
+#endif
+
     private Q_SLOTS:
 
     void newScreenshotClicked();
@@ -101,4 +96,9 @@ class KSWidget : public QWidget
     QAction       *mTakeNewScreenshotAction;
     QAction       *mCancelAction;
     KConfigDialogManager *mConfigManager;
+    QStackedLayout *mStack                       { nullptr };
+    QWidget *placeHolder;
+#ifdef KIMAGEANNOTATOR_FOUND
+    kImageAnnotator::KImageAnnotator *mAnnotator { nullptr };
+#endif
 };
