@@ -1,33 +1,24 @@
 /*
- *  Copyright (C) 2015 Boudhayan Gupta <me@BaloneyGeek.com>
- *  Copyright 2010 Pau Garcia i Quiles <pgquiles@elpauer.org>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <me@BaloneyGeek.com>
+ *  SPDX-FileCopyrightText: 2010 Pau Garcia i Quiles <pgquiles@elpauer.org>
  *  based on code for Gwenview by
- *  Copyright 2008 Aurélien Gâteau <agateau@kde.org>
+ *  SPDX-FileCopyrightText: 2008 Aurélien Gâteau <agateau@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License
- *  as published by the Free Software Foundation; either version 2
- *  of the License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
 */
 
 #include "KSGKipiImageCollectionSelector.h"
+#include <KLocalizedString>
+#include <QVBoxLayout>
 
 KSGKipiImageCollectionSelector::KSGKipiImageCollectionSelector(KIPI::Interface *interface, QWidget *parent)
     : KIPI::ImageCollectionSelector(parent),
       mInterface(interface),
       mListWidget(new QListWidget)
 {
-    Q_FOREACH (const auto &collection, interface->allAlbums()) {
+    const auto allAlbums = interface->allAlbums();
+    for (const auto &collection : allAlbums) {
         QListWidgetItem *item = new QListWidgetItem(mListWidget);
         QString name = collection.name();
         int imageCount = collection.images().size();
@@ -53,7 +44,8 @@ QList<KIPI::ImageCollection> KSGKipiImageCollectionSelector::selectedImageCollec
     QList<KIPI::ImageCollection> selectedList;
     if (item) {
         QString name = item->data(Qt::UserRole).toString();
-        Q_FOREACH (const auto &collection, mInterface->allAlbums()) {
+        const auto allAlbums = mInterface->allAlbums();
+        for (const auto &collection : allAlbums) {
             if (collection.name() == name) {
                 selectedList.append(collection);
                 break;
