@@ -1,6 +1,10 @@
+/*
+ *  SPDX-License-Identifier: GPL-2.0-only OR LGPL-2.0 OR LicenseRef-KDE-Accepted-GPL
+ */
+
 #include <QDir>
 #include <QFile>
-#include <QtTest>
+#include <QTest>
 #include <QUuid>
 
 #include "SpectacleCommon.h"
